nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ahbcr

Struct Ahbcr 

#[repr(transparent)]
pub struct Ahbcr(pub u32);
AHB Bus Control Register

Tuple Fields

0: u32

Implementations

Source

impl Ahbcr

pub const fn aparen(&self) -> Aparen

Parallel mode enabled for AHB triggered Command (both read and write) .

pub const fn set_aparen(&mut self, val: Aparen)

Parallel mode enabled for AHB triggered Command (both read and write) .

pub const fn clrahbrxbuf(&self) -> bool

Clear the status/pointers of AHB RX Buffer. Auto-cleared.

pub const fn set_clrahbrxbuf(&mut self, val: bool)

Clear the status/pointers of AHB RX Buffer. Auto-cleared.

pub const fn clrahbtxbuf(&self) -> bool

Clear the status/pointers of AHB TX Buffer. Auto-cleared. For internal use only.

pub const fn set_clrahbtxbuf(&mut self, val: bool)

Clear the status/pointers of AHB TX Buffer. Auto-cleared. For internal use only.

pub const fn cachableen(&self) -> Cachableen

Enable AHB bus cachable read access support.

pub const fn set_cachableen(&mut self, val: Cachableen)

Enable AHB bus cachable read access support.

pub const fn bufferableen(&self) -> Bufferableen

Enable AHB bus bufferable write access support. This field affects the last beat of AHB write access, refer for more details about AHB bufferable write.

pub const fn set_bufferableen(&mut self, val: Bufferableen)

Enable AHB bus bufferable write access support. This field affects the last beat of AHB write access, refer for more details about AHB bufferable write.

pub const fn prefetchen(&self) -> bool

AHB Read Prefetch Enable.

pub const fn set_prefetchen(&mut self, val: bool)

AHB Read Prefetch Enable.

pub const fn readaddropt(&self) -> Readaddropt

AHB Read Address option bit. This option bit is intend to remove AHB burst start address alignment limitation.

pub const fn set_readaddropt(&mut self, val: Readaddropt)

AHB Read Address option bit. This option bit is intend to remove AHB burst start address alignment limitation.

pub const fn readszalign(&self) -> Readszalign

AHB Read Size Alignment

pub const fn set_readszalign(&mut self, val: Readszalign)

AHB Read Size Alignment