#[repr(transparent)]pub struct Flshcr2(pub u32);Expand description
Flash Control Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Flshcr2
impl Flshcr2
Sourcepub const fn set_ardseqid(&mut self, val: u8)
pub const fn set_ardseqid(&mut self, val: u8)
Sequence Index for AHB Read triggered Command in LUT.
Sourcepub const fn set_ardseqnum(&mut self, val: u8)
pub const fn set_ardseqnum(&mut self, val: u8)
Sequence Number for AHB Read triggered Command in LUT.
Sourcepub const fn set_awrseqid(&mut self, val: u8)
pub const fn set_awrseqid(&mut self, val: u8)
Sequence Index for AHB Write triggered Command.
Sourcepub const fn set_awrseqnum(&mut self, val: u8)
pub const fn set_awrseqnum(&mut self, val: u8)
Sequence Number for AHB Write triggered Command.
Sourcepub const fn awrwait(&self) -> u16
pub const fn awrwait(&self) -> u16
For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface
Sourcepub const fn set_awrwait(&mut self, val: u16)
pub const fn set_awrwait(&mut self, val: u16)
For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface
Sourcepub const fn awrwaitunit(&self) -> Awrwaitunit
pub const fn awrwaitunit(&self) -> Awrwaitunit
AWRWAIT unit
Sourcepub const fn set_awrwaitunit(&mut self, val: Awrwaitunit)
pub const fn set_awrwaitunit(&mut self, val: Awrwaitunit)
AWRWAIT unit
Sourcepub const fn clrinstrptr(&self) -> bool
pub const fn clrinstrptr(&self) -> bool
Clear the instruction pointer which is internally saved pointer by JMP_ON_CS. Refer Programmable Sequence Engine for details.
Sourcepub const fn set_clrinstrptr(&mut self, val: bool)
pub const fn set_clrinstrptr(&mut self, val: bool)
Clear the instruction pointer which is internally saved pointer by JMP_ON_CS. Refer Programmable Sequence Engine for details.