#[repr(transparent)]pub struct Flshcr4(pub u32);Expand description
Flash Control Register 4
Tuple Fields
0: u32Implementations
Sourceimpl Flshcr4
impl Flshcr4
Sourcepub const fn wmopt1(&self) -> bool
pub const fn wmopt1(&self) -> bool
Write mask option bit 1. This option bit could be used to remove AHB write burst start address alignment limitation.
Sourcepub const fn set_wmopt1(&mut self, val: bool)
pub const fn set_wmopt1(&mut self, val: bool)
Write mask option bit 1. This option bit could be used to remove AHB write burst start address alignment limitation.
Sourcepub const fn wmena(&self) -> Wmena
pub const fn wmena(&self) -> Wmena
Write mask enable bit for flash device on port A. When write mask function is needed for memory device on port A, this bit must be set.
Sourcepub const fn set_wmena(&mut self, val: Wmena)
pub const fn set_wmena(&mut self, val: Wmena)
Write mask enable bit for flash device on port A. When write mask function is needed for memory device on port A, this bit must be set.