#[repr(transparent)]pub struct Intr(pub u32);Expand description
Interrupt Register
Tuple Fields
0: u32Implementations
Sourceimpl Intr
impl Intr
Sourcepub const fn ipcmddone(&self) -> bool
pub const fn ipcmddone(&self) -> bool
IP triggered Command Sequences Execution finished interrupt. This interrupt is also generated when there is IPCMDGE or IPCMDERR interrupt generated.
Sourcepub const fn set_ipcmddone(&mut self, val: bool)
pub const fn set_ipcmddone(&mut self, val: bool)
IP triggered Command Sequences Execution finished interrupt. This interrupt is also generated when there is IPCMDGE or IPCMDERR interrupt generated.
Sourcepub const fn set_ipcmdge(&mut self, val: bool)
pub const fn set_ipcmdge(&mut self, val: bool)
IP triggered Command Sequences Grant Timeout interrupt.
Sourcepub const fn set_ahbcmdge(&mut self, val: bool)
pub const fn set_ahbcmdge(&mut self, val: bool)
AHB triggered Command Sequences Grant Timeout interrupt.
Sourcepub const fn ipcmderr(&self) -> bool
pub const fn ipcmderr(&self) -> bool
IP triggered Command Sequences Error Detected interrupt. When an error detected for IP command, this command will be ignored and not executed at all.
Sourcepub const fn set_ipcmderr(&mut self, val: bool)
pub const fn set_ipcmderr(&mut self, val: bool)
IP triggered Command Sequences Error Detected interrupt. When an error detected for IP command, this command will be ignored and not executed at all.
Sourcepub const fn ahbcmderr(&self) -> bool
pub const fn ahbcmderr(&self) -> bool
AHB triggered Command Sequences Error Detected interrupt. When an error detected for AHB command, this command will be ignored and not executed at all.
Sourcepub const fn set_ahbcmderr(&mut self, val: bool)
pub const fn set_ahbcmderr(&mut self, val: bool)
AHB triggered Command Sequences Error Detected interrupt. When an error detected for AHB command, this command will be ignored and not executed at all.
Sourcepub const fn set_iprxwa(&mut self, val: bool)
pub const fn set_iprxwa(&mut self, val: bool)
IP RX FIFO watermark available interrupt.
Sourcepub const fn set_iptxwe(&mut self, val: bool)
pub const fn set_iptxwe(&mut self, val: bool)
IP TX FIFO watermark empty interrupt.
Sourcepub const fn sckstopbyrd(&self) -> bool
pub const fn sckstopbyrd(&self) -> bool
SCLK is stopped during command sequence because Async RX FIFO full interrupt.
Sourcepub const fn set_sckstopbyrd(&mut self, val: bool)
pub const fn set_sckstopbyrd(&mut self, val: bool)
SCLK is stopped during command sequence because Async RX FIFO full interrupt.
Sourcepub const fn sckstopbywr(&self) -> bool
pub const fn sckstopbywr(&self) -> bool
SCLK is stopped during command sequence because Async TX FIFO empty interrupt.
Sourcepub const fn set_sckstopbywr(&mut self, val: bool)
pub const fn set_sckstopbywr(&mut self, val: bool)
SCLK is stopped during command sequence because Async TX FIFO empty interrupt.
Sourcepub const fn ahbbustimeout(&self) -> bool
pub const fn ahbbustimeout(&self) -> bool
AHB Bus timeout interrupt.Refer Interrupts chapter for more details.
Sourcepub const fn set_ahbbustimeout(&mut self, val: bool)
pub const fn set_ahbbustimeout(&mut self, val: bool)
AHB Bus timeout interrupt.Refer Interrupts chapter for more details.
Sourcepub const fn seqtimeout(&self) -> bool
pub const fn seqtimeout(&self) -> bool
Sequence execution timeout interrupt.
Sourcepub const fn set_seqtimeout(&mut self, val: bool)
pub const fn set_seqtimeout(&mut self, val: bool)
Sequence execution timeout interrupt.