#[repr(transparent)]pub struct Mcr0(pub u32);Expand description
Module Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Mcr0
impl Mcr0
Sourcepub const fn set_swreset(&mut self, val: bool)
pub const fn set_swreset(&mut self, val: bool)
Software Reset
Sourcepub const fn set_rxclksrc(&mut self, val: Rxclksrc)
pub const fn set_rxclksrc(&mut self, val: Rxclksrc)
Sample Clock source selection for Flash Reading
Sourcepub const fn set_ardfen(&mut self, val: Ardfen)
pub const fn set_ardfen(&mut self, val: Ardfen)
Enable AHB bus Read Access to IP RX FIFO.
Sourcepub const fn set_atdfen(&mut self, val: Atdfen)
pub const fn set_atdfen(&mut self, val: Atdfen)
Enable AHB bus Write Access to IP TX FIFO.
Sourcepub const fn serclkdiv(&self) -> Serclkdiv
pub const fn serclkdiv(&self) -> Serclkdiv
The serial root clock could be divided inside FlexSPI . See Clocks section for more details on clocking.
Sourcepub const fn set_serclkdiv(&mut self, val: Serclkdiv)
pub const fn set_serclkdiv(&mut self, val: Serclkdiv)
The serial root clock could be divided inside FlexSPI . See Clocks section for more details on clocking.
Sourcepub const fn set_dozeen(&mut self, val: Dozeen)
pub const fn set_dozeen(&mut self, val: Dozeen)
Doze mode enable bit
Sourcepub const fn combinationen(&self) -> bool
pub const fn combinationen(&self) -> bool
This bit is to support Flash Octal mode access by combining Port A and B Data pins (A_DATA[3:0] and B_DATA[3:0]), when Port A and Port B are of 4 bit data width.
Sourcepub const fn set_combinationen(&mut self, val: bool)
pub const fn set_combinationen(&mut self, val: bool)
This bit is to support Flash Octal mode access by combining Port A and B Data pins (A_DATA[3:0] and B_DATA[3:0]), when Port A and Port B are of 4 bit data width.
Sourcepub const fn sckfreerunen(&self) -> bool
pub const fn sckfreerunen(&self) -> bool
This bit is used to force SCLK output free-running. For FPGA applications, external device may use SCLK as reference clock to its internal PLL. If SCLK free-running is enabled, data sampling with loopback clock from SCLK pad is not supported (MCR0[RXCLKSRC]=2).
Sourcepub const fn set_sckfreerunen(&mut self, val: bool)
pub const fn set_sckfreerunen(&mut self, val: bool)
This bit is used to force SCLK output free-running. For FPGA applications, external device may use SCLK as reference clock to its internal PLL. If SCLK free-running is enabled, data sampling with loopback clock from SCLK pad is not supported (MCR0[RXCLKSRC]=2).
Sourcepub const fn ipgrantwait(&self) -> u8
pub const fn ipgrantwait(&self) -> u8
Time out wait cycle for IP command grant.
Sourcepub const fn set_ipgrantwait(&mut self, val: u8)
pub const fn set_ipgrantwait(&mut self, val: u8)
Time out wait cycle for IP command grant.
Sourcepub const fn ahbgrantwait(&self) -> u8
pub const fn ahbgrantwait(&self) -> u8
Timeout wait cycle for AHB command grant.
Sourcepub const fn set_ahbgrantwait(&mut self, val: u8)
pub const fn set_ahbgrantwait(&mut self, val: u8)
Timeout wait cycle for AHB command grant.