nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Mcr1

Struct Mcr1 

#[repr(transparent)]
pub struct Mcr1(pub u32);
Module Control Register 1

Tuple Fields

0: u32

Implementations

Source

impl Mcr1

pub const fn ahbbuswait(&self) -> u16

AHB Read/Write access to Serial Flash Memory space will timeout if not data received from Flash or data not transmitted after AHBBUSWAIT * 1024 ahb clock cycles, AHB Bus will get an error response

pub const fn set_ahbbuswait(&mut self, val: u16)

AHB Read/Write access to Serial Flash Memory space will timeout if not data received from Flash or data not transmitted after AHBBUSWAIT * 1024 ahb clock cycles, AHB Bus will get an error response

pub const fn seqwait(&self) -> u16

Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles

pub const fn set_seqwait(&mut self, val: u16)

Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles