#[repr(transparent)]pub struct Ahbcr(pub u32);Expand description
AHB Bus Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Ahbcr
impl Ahbcr
Sourcepub const fn aparen(&self) -> Aparen
pub const fn aparen(&self) -> Aparen
Parallel mode enabled for AHB triggered Command (both read and write) .
Sourcepub const fn set_aparen(&mut self, val: Aparen)
pub const fn set_aparen(&mut self, val: Aparen)
Parallel mode enabled for AHB triggered Command (both read and write) .
Sourcepub const fn clrahbrxbuf(&self) -> bool
pub const fn clrahbrxbuf(&self) -> bool
Clear the status/pointers of AHB RX Buffer. Auto-cleared.
Sourcepub const fn set_clrahbrxbuf(&mut self, val: bool)
pub const fn set_clrahbrxbuf(&mut self, val: bool)
Clear the status/pointers of AHB RX Buffer. Auto-cleared.
Sourcepub const fn clrahbtxbuf(&self) -> bool
pub const fn clrahbtxbuf(&self) -> bool
Clear the status/pointers of AHB TX Buffer. Auto-cleared. For internal use only.
Sourcepub const fn set_clrahbtxbuf(&mut self, val: bool)
pub const fn set_clrahbtxbuf(&mut self, val: bool)
Clear the status/pointers of AHB TX Buffer. Auto-cleared. For internal use only.
Sourcepub const fn cachableen(&self) -> Cachableen
pub const fn cachableen(&self) -> Cachableen
Enable AHB bus cachable read access support.
Sourcepub const fn set_cachableen(&mut self, val: Cachableen)
pub const fn set_cachableen(&mut self, val: Cachableen)
Enable AHB bus cachable read access support.
Sourcepub const fn bufferableen(&self) -> Bufferableen
pub const fn bufferableen(&self) -> Bufferableen
Enable AHB bus bufferable write access support. This field affects the last beat of AHB write access, refer for more details about AHB bufferable write.
Sourcepub const fn set_bufferableen(&mut self, val: Bufferableen)
pub const fn set_bufferableen(&mut self, val: Bufferableen)
Enable AHB bus bufferable write access support. This field affects the last beat of AHB write access, refer for more details about AHB bufferable write.
Sourcepub const fn prefetchen(&self) -> bool
pub const fn prefetchen(&self) -> bool
AHB Read Prefetch Enable.
Sourcepub const fn set_prefetchen(&mut self, val: bool)
pub const fn set_prefetchen(&mut self, val: bool)
AHB Read Prefetch Enable.
Sourcepub const fn readaddropt(&self) -> Readaddropt
pub const fn readaddropt(&self) -> Readaddropt
AHB Read Address option bit. This option bit is intend to remove AHB burst start address alignment limitation.
Sourcepub const fn set_readaddropt(&mut self, val: Readaddropt)
pub const fn set_readaddropt(&mut self, val: Readaddropt)
AHB Read Address option bit. This option bit is intend to remove AHB burst start address alignment limitation.
Sourcepub const fn readszalign(&self) -> Readszalign
pub const fn readszalign(&self) -> Readszalign
AHB Read Size Alignment
Sourcepub const fn set_readszalign(&mut self, val: Readszalign)
pub const fn set_readszalign(&mut self, val: Readszalign)
AHB Read Size Alignment